from django.apps import AppConfig


class ModalConfig(AppConfig):
    name = 'django_modals'
